# 22.11.2 (2022-11-30)
* Added path to template in module.py to avoid erros in backend page preview

# 22.11.1 (2022-11-12)
* Updated ADOBE API script call to new version.

# 0.1.0 (2022-09-04)
* Initial version, based on private repository dj-apps-lxp

# 22.10.1 (2022-10-22)
* Works with Wagtail 4.0 and django-cjkcms
* Switched to calendar versioning
